pub struct PsqlClientRef<'a> { /* private fields */ }Trait Implementations
Sourceimpl<'a> Clone for PsqlClientRef<'a>
impl<'a> Clone for PsqlClientRef<'a>
Sourcefn clone(&self) -> PsqlClientRef<'a>
fn clone(&self) -> PsqlClientRef<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for PsqlClientRef<'a>
impl<'a> Debug for PsqlClientRef<'a>
Sourceimpl From<&PsqlClientRef<'_>> for PsqlClient
impl From<&PsqlClientRef<'_>> for PsqlClient
Sourcefn from(r: &PsqlClientRef<'_>) -> Self
fn from(r: &PsqlClientRef<'_>) -> Self
Converts to this type from the input type.
Sourceimpl From<PsqlClientRef<'_>> for PsqlClient
impl From<PsqlClientRef<'_>> for PsqlClient
Sourcefn from(value: PsqlClientRef<'_>) -> Self
fn from(value: PsqlClientRef<'_>) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<PsqlClientRef<'a>> for &'a [u8]
impl<'a> From<PsqlClientRef<'a>> for &'a [u8]
Sourcefn from(value: PsqlClientRef<'a>) -> Self
fn from(value: PsqlClientRef<'a>) -> Self
Converts to this type from the input type.
Sourceimpl<'a> FromBytesRef<'a> for PsqlClientRef<'a>
impl<'a> FromBytesRef<'a> for PsqlClientRef<'a>
Sourcefn from_bytes_unchecked(_bytes: &'a [u8]) -> Self
fn from_bytes_unchecked(_bytes: &'a [u8]) -> Self
Sourcefn from_bytes(bytes: &'a [u8]) -> Result<Self, ValidationError>
fn from_bytes(bytes: &'a [u8]) -> Result<Self, ValidationError>
Converts a slice of bytes into a
LayerRef type, returning an error if the bytes would
not form a valid layer.Sourceimpl<'a> IndexLayerRef<'a> for PsqlClientRef<'a>
impl<'a> IndexLayerRef<'a> for PsqlClientRef<'a>
Sourcefn get_layer<T: LayerRef<'a> + FromBytesRef<'a>>(&'a self) -> Option<T>
fn get_layer<T: LayerRef<'a> + FromBytesRef<'a>>(&'a self) -> Option<T>
Retrieves a reference to the first sublayer of type
T, if such a sublayer exists. Read moreSourcefn get_nth_layer<T: LayerRef<'a> + FromBytesRef<'a> + BaseLayerMetadata>(
&'a self,
n: usize,
) -> Option<T>
fn get_nth_layer<T: LayerRef<'a> + FromBytesRef<'a> + BaseLayerMetadata>( &'a self, n: usize, ) -> Option<T>
Sourcefn index_layer<T: LayerRef<'a> + FromBytesRef<'a> + BaseLayerMetadata>(
&'a self,
) -> T
fn index_layer<T: LayerRef<'a> + FromBytesRef<'a> + BaseLayerMetadata>( &'a self, ) -> T
Retrieves a reference to the first sublayer of type
T. Read moreSourcefn index_nth_layer<T: LayerRef<'a> + FromBytesRef<'a> + BaseLayerMetadata>(
&'a self,
n: usize,
) -> T
fn index_nth_layer<T: LayerRef<'a> + FromBytesRef<'a> + BaseLayerMetadata>( &'a self, n: usize, ) -> T
Sourceimpl LayerIdentifier for PsqlClientRef<'_>
impl LayerIdentifier for PsqlClientRef<'_>
Sourceimpl LayerLength for PsqlClientRef<'_>
impl LayerLength for PsqlClientRef<'_>
Sourceimpl<'a> LayerObjectMetadata for PsqlClientRef<'a>
impl<'a> LayerObjectMetadata for PsqlClientRef<'a>
Sourcefn layer_metadata(&self) -> &dyn LayerMetadata
fn layer_metadata(&self) -> &dyn LayerMetadata
Static metadata associated with the given layer. This method is normally only used
internally or when defining a custom
Layer type.Sourceimpl<'a> LayerObjectName for PsqlClientRef<'a>
impl<'a> LayerObjectName for PsqlClientRef<'a>
Sourcefn layer_name(&self) -> &'static str
fn layer_name(&self) -> &'static str
The name of the layer, usually (though not guaranteed to be) the same as the name of the
struct. Read more
Sourceimpl<'a> LayerOffset for PsqlClientRef<'a>
impl<'a> LayerOffset for PsqlClientRef<'a>
Sourceimpl<'a> ToBoxedLayer for PsqlClientRef<'a>
Available on crate feature alloc only.
impl<'a> ToBoxedLayer for PsqlClientRef<'a>
Available on crate feature
alloc only.Sourcefn to_boxed_layer(&self) -> Box<dyn LayerObject>
fn to_boxed_layer(&self) -> Box<dyn LayerObject>
Clone the given instance in a
Box and return it as a dyn Layer type.Sourceimpl ToLayer for PsqlClientRef<'_>
Available on crate feature alloc only.
impl ToLayer for PsqlClientRef<'_>
Available on crate feature
alloc only.Sourceimpl<'a> Validate for PsqlClientRef<'a>
impl<'a> Validate for PsqlClientRef<'a>
impl<'a> Copy for PsqlClientRef<'a>
impl<'a> LayerRef<'a> for PsqlClientRef<'a>
impl<'a> StatelessLayer for PsqlClientRef<'a>